function OnInit(initData)
{
	initData.name = "filtermenu";
	initData.vars("name") = initData.name;
	initData.desc = "Named Filter Menu";
	initData.copyright = "(c) 2018 Aussie";
	initData.version = "1.1 (March 29 2018)";
	initData.vars("version") = initData.version;
	initData.default_enable = true;
	
	// v1.0 2018-03-21
	// v1.1 2018-03-29 Add Hide Unselected button
	
	var cmd = initData.AddCommand();
	cmd.name = initData.name;
	cmd.method = "do_main";
	cmd.desc = initData.desc;
	cmd.label = initData.name;
	cmd.template = "parms/m";
	
	initData.config_desc = DOpus.create.map();
	initData.config.dbg = false;
	initData.config_desc("dbg") = 'Set to TRUE to write trace information to "Other" log.';
	initData.config.edit_button = false;
	initData.config_desc("edit_button") = 'Set to TRUE to enable "Prefs Page=FILTERS" button';
}

//-- Global Variables

var d, f, c, fsu;
var src, tgt, dlg;
var msg, btns, title;
var item, str;
var dbg, edit_button;

function do_main(clickData)
{
	dbg = Script.config.dbg;
	if (dbg) DOpus.output(Script.vars("name")+" version "+Script.vars("version")+" starting..");
	edit_button = Script.config.edit_button;
	d = clickData;
	f = d.func;
	c = f.command;
	c.deselect=false;
	fsu = DOpus.FSUtil;
	src = f.sourcetab;
	dlg = src.dlg
	dlg.window = src;
	dlg.template = "filtermenu";
	dlg.detach = true;
	dlg.create;
	var iteration = 0;
	var msg_obj, ctl_name;
	dlg.control("static1").label = "Choose a filter and an option, then Add, Replace or Apply.";
	// Suppress Edit and Refresh buttons unless the user has explicitly asked for them
	dlg.control("Edit").visible = (edit_button) ? true : false;
	dlg.control("Refresh").visible = (edit_button) ? true : false;
	configure_action_buttons();
	refresh_listbox();
	dlg.show;
	do{
		msg_obj = dlg.getmsg();
		if (msg_obj==false) break; // User clicked X to close the dialog
		ctl_name = msg_obj.control;
		if (dbg){
			str = iteration++;
			str+= " : msg_obj.event = " + msg_obj.event;
			str+= " : msg_obj.control = " + ctl_name;
			DOpus.output(str);
		}
		if (msg_obj.control=="Quit") return;
		// User might have switched tabs
		c.setsourcetab(DOpus.listers.lastactive.activetab);
		if (msg_obj.control=="Add") process(true);
		else if (msg_obj.control=="Replace") process(false);
		else if (msg_obj.control=="Select") configure_action_buttons();
		else if (msg_obj.control=="Deselect") configure_action_buttons();
		else if (msg_obj.control=="Hide") configure_action_buttons();
		else if (msg_obj.control=="Unmatched") configure_action_buttons();
		else if (msg_obj.control=="ShowAll") c.runcommand("Select NOPATTERN SHOWHIDDEN");
		else if (msg_obj.control=="HideSelected") c.runcommand("Select NOPATTERN HIDESEL");
		else if (msg_obj.control=="HideUnselected") c.runcommand("Select NOPATTERN HIDEUNSEL");
		else if (msg_obj.control=="SelectAll") c.runcommand("Select ALL");
		else if (msg_obj.control=="SelectNone") c.runcommand("Select NONE");
		else if (msg_obj.control=="Invert") c.runcommand("Select INVERT");
		else if (msg_obj.control=="Simple"){
			c.clear;
			c.addline("@noprogress");
			c.addline("Select SIMPLE");
			c.run;
		}
		else if (msg_obj.control=="Advanced"){
			str = "Select ADVANCED";
			item = dlg.control("listbox1").value;
			if (item.name!="") str = str + '="' + item.name + '"';
			c.clear;
			c.addline("@noprogress");
			c.addline(str);
			c.run;
		}
		else if (msg_obj.control=="Edit") c.runcommand("Prefs Page=FILTERS");
		else if (msg_obj.control=="Refresh") refresh_listbox();
	}
	while (msg_obj);
}

function configure_action_buttons(){
	if (dlg.control("Select").value){
		dlg.control("Add").label = "Add Selected";
		dlg.control("Replace").label = "Replace Selected";
		dlg.control("Replace").visible = true;
	}
	else{
		dlg.control("Add").label = "Apply";
		dlg.control("Replace").visible = false;
	}
}

function refresh_listbox(){
	dlg.control("listbox1").removeItem(-1);
	var filters = fsu.readdir("/dopusdata\\filters");
	var next;
	while (!filters.complete){
		next = filters.next;
		dlg.control("listbox1").additem(next.name_stem);
	}
}

function process(add){
	item = dlg.control("listbox1").value;
	if (dbg) DOpus.output("item.name = " + item.name);
	if (item.name=="") return;
	var cmdstr = 'Select FILTER "' + item.name + '" FILTERFLAGS=';
	if (dlg.control("Select").value) cmdstr = cmdstr + "select";
	else if (dlg.control("Deselect").value) cmdstr = cmdstr + "deselect";
	else if (dlg.control("Hide").value) cmdstr = cmdstr + "hide";
	else if (dlg.control("Unmatched").value) cmdstr = cmdstr + "hidenomatch";
	if (add==false) cmdstr = cmdstr + " DESELECTNOMATCH";
	if (dbg) DOpus.output("cmdstr = " + cmdstr);
	c.runcommand(cmdstr);
	dlg.control("Select").value = true;
}

==SCRIPT RESOURCES
<resources>
	<resource name="filtermenu" type="dialog">
		<dialog fontsize="8" height="228" lang="english" resize="yes" title="Filter Menu" width="330">
			<control height="156" name="listbox1" resize="wh" type="listbox" width="144" x="12" y="36" />
			<control height="14" name="ShowAll" resize="x" title="Show All" type="button" width="60" x="174" y="180" />
			<control height="14" name="HideUnselected" resize="x" title="Hide Unselected" type="button" width="66" x="252" y="60" />
			<control height="14" name="SelectAll" resize="x" title="Select All" type="button" width="66" x="252" y="84" />
			<control height="14" name="SelectNone" resize="x" title="Select None" type="button" width="66" x="252" y="108" />
			<control halign="left" height="18" name="static1" type="static" width="300" x="12" y="12" />
			<control height="14" name="Replace" resize="x" title="Replace Selected" type="button" width="66" x="90" y="204" />
			<control height="14" name="Quit" resize="x" title="Quit" type="button" width="66" x="252" y="204" />
			<control height="84" name="group2" resize="x" title="Filter Option" type="group" width="72" x="168" y="36" />
			<control checked="yes" group="yes" height="10" name="Select" resize="x" title="Select" type="radio" width="64" x="174" y="48" />
			<control height="10" name="Deselect" resize="x" title="Deselect" type="radio" width="64" x="174" y="66" />
			<control height="10" name="Hide" resize="x" title="Hide" type="radio" width="64" x="174" y="84" />
			<control height="10" name="Unmatched" resize="x" title="Unmatched" type="radio" width="64" x="174" y="102" />
			<control height="14" name="Invert" resize="x" title="Invert Selected" type="button" width="66" x="252" y="132" />
			<control height="14" name="Advanced" resize="x" title="Advanced" type="button" width="66" x="252" y="180" />
			<control height="14" name="Simple" resize="x" title="Simple" type="button" width="66" x="252" y="156" />
			<control height="14" name="Add" resize="x" title="Add to Selected" type="button" width="66" x="12" y="204" />
			<control height="14" name="Edit" resize="x" title="Edit Filters" type="button" width="60" x="174" y="132" />
			<control height="14" name="Refresh" resize="x" title="Refresh List" type="button" width="60" x="174" y="156" />
			<control height="14" name="HideSelected" resize="x" title="Hide Selected" type="button" width="66" x="252" y="36" />
		</dialog>
	</resource>
</resources>